/*
 *  Kylin security execute control and Box module（模块，包功能介绍）
 *
 *  This file contains the definitions needed for Kylin security exectl
 *  functions
 *
 *  Authors:  WKL <wangkanglong@kylinos.cn>
 *
 *  Copyright (C) 2017,Tianjin KYLIN Information Technology Co., Ltd.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef KYSEC_DEVCTL_H
#define KYSEC_DEVCTL_H

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>


#define bool char
#define true 1
#define false 0

#define KYSEC_DEVCTL_XML_PATH "/etc/kysec/devctl/devctl.xml"
#define SSID_MAX	128

//设备类型
enum kysec_dev_type {
	KYSEC_USB = 1,
	KYSEC_SERIAL,			//串口
	KYSEC_PARALLEL,			//并口
	KYSEC_PS2,			//ps/2接口
	KYSEC_HDMI,			//HDMI接口
	KYSEC_VGA,			//VGA接口
	KYSEC_DVI,			//DVI接口
	KYSEC_NETINF,			//网口
	KYSEC_TYPEC,			//TYPE-C接口
	KYSEC_CDROM,			//光驱
	KYSEC_PRINTER,			//非usb打印机
	KYSEC_WIRELESS,			//无线管控
	KYSEC_ETHERNET,			//有线网络
	KYSEC_BLUETOOTH,		//蓝牙
	KYSEC_CAMERA,			//摄像头
	KYSEC_SCANNER,			//扫描仪
	KYSEC_AUDIO,			//音频
	KYSEC_DEV_MAX
};

//usb设备的类型
enum kysec_usb_type {
	KYSEC_USB_STORAGE = 1,     	//usb存储设备
	KYSEC_USB_CDROM,
	KYSEC_USB_KEYBOARD,		//usb键盘
	KYSEC_USB_MOUSE,		//usb鼠标
	KYSEC_USB_PRINTER,		//usb打印机
	KYSEC_USB_MAX
};

struct kysec_devctl_info {
	int type;		//设备类型
	int usb_subtype;	//usb设备类型
	unsigned int pid;	//设备pid
	unsigned int vid;	//设备vid
	int perm;		//设备权限
};

struct kysec_devctl_ssid {
	char blkssid[SSID_MAX];
};


/**
 * @name: kysec_devctl_add_perm
 * @Descripttion: 添加设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1:出错
 */
int kysec_devctl_add_perm(int dtype, int utype, unsigned int dpid, unsigned int dvid, int dperm);


/**
 * @name: kysec_devctl_remove_perm
 * @Descripttion: 删除设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1:出错
 */
int kysec_devctl_remove_perm(int dtype, int utype, unsigned int dpid, unsigned int dvid, int dperm);

/**
 * @name: kysec_devctl_change_perm
 * @Descripttion: 修改设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1：出错
 */
int kysec_devctl_update_perm(int dtype, int utype, unsigned int dpid, unsigned int dvid, int dperm);

/**
 * @name: kysec_devctl_wireless_ctl_add
 * @Descripttion: 添加无线网络热点名称到黑名单
 * @msg:
 * @param {const char} *  热点名称
 * @return 0:成功，-1：出错
 */
int kysec_devctl_wireless_ctl_add(char * ssid);

/**
 * @name:  kysec_devctl_wireless_ctl_del
 * @Descripttion: 删除黑名单中的无线网络热点
 * @msg:
 * @param {const char} *    热点名称
 * @return {*}  0:成功，-1：出错
 */
int kysec_devctl_wireless_ctl_del(char * ssid);


/**
 * @name: kysec_devctl_read_all_dev_data
 * @Descripttion: 获取所有设备的权限
 * @msg:
 * @param {int} *count  添加的设备个数
 * @return {*}
 */
struct kysec_devctl_info * kysec_devctl_read_all_dev_data(int *count);


/**
 * @name: kysec_devctl_read_all_ssid_data
 * @Descripttion: 获取所有的热点黑名单
 * @msg:
 * @param {int} *count  黑名单的个数
 * @return {*}
 */
struct kysec_devctl_ssid * kysec_devctl_read_all_ssid_data(int *count);

#endif
